labeltools.label_vertical_moments_in_expr_with_interval_class_vectors
=====================================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_interval_class_vectors.label_vertical_moments_in_expr_with_interval_class_vectors
